==> xmule_1.8.2b.orig.tar.gz: xmule-1.8.2b/src/PPgTweaks.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPG_TWEAKS_H
#define PPG_TWEAKS_H

#include "Preferences.h"
#include "resource.h"
#include "Wizard.h"

#include <wx/panel.h>
// CPPgTweaks dialog

class CPPgTweaks : public wxPanel
{
  DECLARE_DYNAMIC_CLASS(CPPgTweaks)
	//DECLARE_DYNAMIC(CPPgTweaks)

    CPPgTweaks() {};
public:
	CPPgTweaks(wxWindow* parent);
	virtual ~CPPgTweaks();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs;}

// Dialog Data
	enum { IDD = IDD_PPG_TWEAKS };
protected:
	CPreferences *app_prefs;
	uint8 m_iFileBufferSize;
	uint8 m_iQueueSize;
	wxPanel* _panel;

#if 0
	//{{AFX_MSG(CSpinToolBar)
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	//}}AFX_MSG

	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support

	DECLARE_MESSAGE_MAP()
#endif
	  DECLARE_EVENT_TABLE()

	  void OnHScroll(wxScrollEvent& evt);
public:
	virtual BOOL OnInitDialog();
	void LoadSettings(void);
	virtual BOOL OnApply();
	//afx_msg void OnSettingsChange()					{ SetModified(); }

	void Localize(void);

};

#endif

==> xmule_1.10.0b.orig.tar.gz: xmule-1.10.0b.orig/src/PPgTweaks.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004, 2005 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef PPG_TWEAKS_H
#define PPG_TWEAKS_H

#include "resource.h"

#include <wx/panel.h>

class CPreferences;

class CPPgTweaks : public wxPanel
{
  DECLARE_DYNAMIC_CLASS(CPPgTweaks)
	//DECLARE_DYNAMIC(CPPgTweaks)

    CPPgTweaks() {};
public:
	CPPgTweaks(wxWindow* parent);
	virtual ~CPPgTweaks();

	void SetPrefs(CPreferences* in_prefs) {	app_prefs = in_prefs;}

// Dialog Data
	enum { IDD = IDD_PPG_TWEAKS };
protected:
	CPreferences *app_prefs;
	wxUint8 m_iFileBufferSize;
	wxUint8 m_iQueueSize;
	wxPanel* _panel;

#if 0
	//{{AFX_MSG(CSpinToolBar)
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	//}}AFX_MSG

	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support

	DECLARE_MESSAGE_MAP()
#endif
	  DECLARE_EVENT_TABLE()

	  void OnHScroll(wxScrollEvent& evt);
public:
	virtual bool OnInitDialog();
	void LoadSettings(void);
	virtual bool OnApply();
	//afx_msg void OnSettingsChange()					{ SetModified(); }

	void Localize(void);

};

#endif
